aboutsummaryrefslogtreecommitdiff
path: root/lib/select.c
diff options
context:
space:
mode:
authorYang Tse <yangsita@gmail.com>2007-03-26 23:23:46 +0000
committerYang Tse <yangsita@gmail.com>2007-03-26 23:23:46 +0000
commitfba4cd0e625cdba3561b3530317ba87ae348aeaf (patch)
tree0b245f00a4f21478d863db7cdd49a92797ee8cf9 /lib/select.c
parent2166645ce4091b14ef6fd25c594d184c4f700ba5 (diff)
Internal function Curl_select() renamed to Curl_socket_ready()
Diffstat (limited to 'lib/select.c')
-rw-r--r--lib/select.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/select.c b/lib/select.c
index 4e6c3046d..27f85fac8 100644
--- a/lib/select.c
+++ b/lib/select.c
@@ -84,8 +84,8 @@
/*
* Internal function used for waiting a specific amount of ms
* in Curl_select() and Curl_poll() when no file descriptor is
* provided to wait on, just being used to delay execution.
* WinSock select() and poll() timeout mechanisms need a valid
* socket descriptor in a not null file descriptor set to work.
* Waiting indefinitely with this function is not allowed, a
@@ -160,7 +160,7 @@ static int wait_ms(int timeout_ms)
* 0 = timeout
* CSELECT_IN | CSELECT_OUT | CSELECT_ERR
*/
-int Curl_select(curl_socket_t readfd, curl_socket_t writefd, int timeout_ms)
+int Curl_socket_ready(curl_socket_t readfd, curl_socket_t writefd, int timeout_ms)
{
#ifdef HAVE_POLL_FINE
struct pollfd pfd[2];
@@ -84,8 +84,8 @@
/*
* Internal function used for waiting a specific amount of ms
- * in Curl_select() and Curl_poll() when no file descriptor is
- * provided to wait on, just being used to delay execution.
+ * in Curl_socket_ready() and Curl_poll() when no file descriptor
+ * is provided to wait on, just being used to delay execution.
* WinSock select() and poll() timeout mechanisms need a valid
* socket descriptor in a not null file descriptor set to work.